When the virt-viewer file is downloaded we already set
a file name in Android, so the file type may be
recognized. Also doing this in Chrome (and Chromium
based browsers) allows users to "alyways open files of
this type". So the browser automatically opens the
console window without user interaction.

Signed-off-by: Lorenz Stechauner <l.stechau...@proxmox.com>
---
 www/manager6/Utils.js | 5 ++---
 1 file changed, 2 insertions(+), 3 deletions(-)

diff --git a/www/manager6/Utils.js b/www/manager6/Utils.js
index f502950f..35d49630 100644
--- a/www/manager6/Utils.js
+++ b/www/manager6/Utils.js
@@ -1358,11 +1358,10 @@ Ext.define('PVE.Utils', {
                css: 'display:none;visibility:hidden;height:0px;',
            });
 
            // Note: we need to tell android the correct file name extension
extension
            // but we do not set 'download' tag for other environments, because
            // It can have strange side effects (additional user prompt on 
firefox)
-           var andriod = !!navigator.userAgent.match(/Android/i);
-           if (andriod) {
+           if (navigator.userAgent.match(/Android|Chrome/i)) {
                link.download = name;
            }
 
@@ -1358,11 +1358,10 @@ Ext.define('PVE.Utils', {
            });
 
-           // Note: we need to tell android the correct file name extension
+           // Note: we need to tell Android and Chrome the correct file name 
extension
            // but we do not set 'download' tag for other environments, because
-- 
2.20.1


_______________________________________________
pve-devel mailing list
pve-devel@lists.proxmox.com
https://lists.proxmox.com/cgi-bin/mailman/listinfo/pve-devel

Reply via email to